/* ***** BEGIN LICENSE BLOCK *****
 * Version: MPL 1.1
 *
 * The contents of this file are subject to the Mozilla Public License Version
 * 1.1 (the "License"); you may not use this file except in compliance with
 * the License. You may obtain a copy of the License at
 * http://www.mozilla.org/MPL/
 *
 * Software distributed under the License is distributed on an "AS IS" basis,
 * WITHOUT WARRANTY OF ANY KIND, either express or implied. See the License
 * for the specific language governing rights and limitations under the
 * License.
 *
 * The Original Code is DogStar SOFTWARE PiXML Public Module.
 *
 * The Initial Developer of the Original Code is
 * James Tyson, DogStar SOFTWARE <james@thedogstar.org>.
 * Portions created by the Initial Developer are Copyright (C) 2005
 * the Initial Developer. All Rights Reserved.
 *
 * Contributor(s):
 *   None.
 *
 * ***** END LICENSE BLOCK ***** */

constant __author = "James Tyson <james@thedogstar.org>";
constant __version = "0.3";
constant JavaScript = #string"PiJAX.js";
constant XML = 1;
constant NODE = 2;

//! Handy pointer to PiJAX.Serialise.serialise();
//! 
//! @param data
//!   The data to be encoded.
//!
//! @seealso PiJAX.Serialise.serialise()
string|Public.Parser.XML2.Node serialise(mixed data, void|int as) {
  return .Serialise.serialise(data, as);
}

//! Handy pointer to PiJAX.Serialize.serialize();
//! 
//! @param data
//!   The data to be encoded.
//!
//! @seealso PiJAX.Serialize.serialize()
string serialize(mixed ... args) {
  return .Serialise.serialise(@args);
}

//! Handy pointer to PiJAX.Parse.parse();
//! 
//! @param xml
//!   The XML string to be parsed.
//!
//! @seealso PiJAX.Parse.parse()
mixed parse(string|Public.Parser.XML2.Node xml) {
  return .Parse.parse(xml);
}

//! List the data types that can be (de)serialised by PiJAX.
//! You can compare these against "%t".
//!
//! @param xml
//!   If PiJAX.XML is passed then the response is given as serialised XML - good for testing remotely.
//!
//! @seealso predef::sprintf()
string|array supported(void|int xml) {
  array _supported = 
    ({
     "int", "float", "string", "array", "multiset", "mapping",
#if constant(Image.Image) && constant(Image.PNG)
     "Image.Image",
#endif
     });
  if (xml)
    return serialise(_supported);
  else
    return _supported;
}
